<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Permission\Models\Group;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Permission\Requests\StoreRoleRequest;
use EventPortal\Domain\Permission\Resources\Group as GroupResource;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Arr;
use Illuminate\Support\Str;

class RoleController extends Controller
{
    public function store(StoreRoleRequest $request): JsonResponse
    {
        Role::create([
            'name' => Str::kebab($request->name),
            'label' => $request->name,
        ]);

        $roles = Role::all();
        $columns = Arr::collapse($roles->map(static function (Role $role) {
            return [$role->name => $role->label];
        }));

        $data = Group::with('permissions')
            ->get(['id', 'name', 'label'])
            ->map(static function (Group $group) use ($roles): array {
                return (new GroupResource($group, $roles))->toArray();
            });

        return response()->json(['permissions' => compact('columns', 'data')]);
    }
}
